summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/3rdparty/libpng/pngtest.c
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/3rdparty/libpng/pngtest.c')
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngtest.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngtest.c b/tqtinterface/qt4/src/3rdparty/libpng/pngtest.c
index 66bb2a0..cc8209e 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngtest.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngtest.c
@@ -58,7 +58,7 @@
# endif
#endif
/* Makes pngtest verbose so we can tqfind problems (needs to be before png.h) */
#ifndef PNG_DEBUG
# define PNG_DEBUG 0
#endif
@@ -290,7 +290,7 @@ static int wrote_question = 0;
/* These copies of the default read/write functions come from pngrio.c and */
/* pngwio.c. They allow "don't include stdio" testing of the library. */
/* This is the function that does the actual reading of data. If you are
- not reading from a standard C stream, you should create a tqreplacement
+ not reading from a standard C stream, you should create a replacement
read_data function and use it at run time with png_set_read_fn(), rather
than changing the library. */
@@ -374,7 +374,7 @@ pngtest_flush(png_structp png_ptr)
#endif
/* This is the function that does the actual writing of data. If you are
- not writing to a standard C stream, you should create a tqreplacement
+ not writing to a standard C stream, you should create a replacement
write_data function and use it at run time with png_set_write_fn(), rather
than changing the library. */
#ifndef USE_FAR_KEYWORD
@@ -454,7 +454,7 @@ pngtest_warning(png_structp png_ptr, png_const_charp message)
fprintf(STDERR, "%s: libpng warning: %s\n", name, message);
}
-/* This is the default error handling function. Note that tqreplacements for
+/* This is the default error handling function. Note that replacements for
* this function MUST NOT RETURN, or the program will likely crash. This
* function is used by default, or if the program supplies NULL for the
* error function pointer in png_set_error_fn().
@@ -627,7 +627,7 @@ test_one_file(PNG_CONST char *inname, PNG_CONST char *outname)
if ((fpin = fopen(inname, "rb")) == NULL)
#endif
{
- fprintf(STDERR, "Could not tqfind input file %s\n", inname);
+ fprintf(STDERR, "Could not find input file %s\n", inname);
return (1);
}
@@ -1208,7 +1208,7 @@ test_one_file(PNG_CONST char *inname, PNG_CONST char *outname)
if ((fpin = fopen(inname, "rb")) == NULL)
#endif
{
- fprintf(STDERR, "Could not tqfind file %s\n", inname);
+ fprintf(STDERR, "Could not find file %s\n", inname);
return (1);
}
@@ -1219,7 +1219,7 @@ test_one_file(PNG_CONST char *inname, PNG_CONST char *outname)
if ((fpout = fopen(outname, "rb")) == NULL)
#endif
{
- fprintf(STDERR, "Could not tqfind file %s\n", outname);
+ fprintf(STDERR, "Could not find file %s\n", outname);
FCLOSE(fpin);
return (1);
}
@@ -58,7 +58,7 @@
# endif
#endif
-/* Makes pngtest verbose so we can tqfind problems (needs to be before png.h) */
+/* Makes pngtest verbose so we can find problems (needs to be before png.h) */
#ifndef PNG_DEBUG
# define PNG_DEBUG 0